/*
 *    (c) Copyright 2015 Hewlett-Packard Development Company, L.P.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
$(document).ready(function () {
  'use strict';

  var $sidenav = $('#sidebar');
  var $mask = $(document.createElement('div'))
    .prop('id', 'md-hamburger-mask')
    .appendTo($('#content_body'));

  // Hamburger Happiness !!!
  $(document).on('click', '.md-hamburger', function () {
    $(this).find('.md-hamburger-layer')
      .toggleClass('md-hamburger-arrow')
      .toggleClass('md-hamburger-menu');

    $mask.toggleClass('active');
    $sidenav.toggleClass('active');
  });
});
